@@ -3,12 +3,12 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 from sqlbuilder import smartsql as sb
 from pyar import exc, url, util
 from pyar.dialects import connection
-import logging
+import logging, traceback
 import pyar.settings
 
 T, TA, F, A, E, qs = sb.Table, sb.TableAlias, sb.Field, sb.Alias, sb.Expr, sb.QuerySet
@@ -216,9 +216,11 @@ class Model(ModelBase):
     def __enter__(self):
         return self
 
-    def __exit__(self, type, value, traceback):
+    def __exit__(self, type, value, _traceback):
         del self
-        if traceback is not None:
+        if _traceback is not None:
+            if self._debug_:
+                self.logger.debug(traceback.format_exc())
             return False
         return True
 
